==> mongodb-5.0.32.gh.tar.gz: mongo-r5.0.32/src/mongo/transport/ssl_connection_context.h <==
/**
 *    Copyright (C) 2020-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <memory>

#include "mongo/config.h"
#include "mongo/util/net/ssl_options.h"
#include "mongo/util/net/ssl_types.h"

namespace asio {

namespace ssl {
class context;
}  // namespace ssl
}  // namespace asio

namespace mongo {

class SSLManagerInterface;

namespace transport {

#ifdef MONGO_CONFIG_SSL
struct SSLConnectionContext {
    std::unique_ptr<asio::ssl::context> ingress;
    std::unique_ptr<asio::ssl::context> egress;
    std::shared_ptr<SSLManagerInterface> manager;
    // If this Context was created from transient SSL params this contains the URI of the target
    // cluster. It can also be used to determine if the context is indeed transient.
    std::optional<std::string> targetClusterURI;

    ~SSLConnectionContext();
};
#endif

#ifndef MONGO_CONFIG_SSL
struct SSLConnectionContext {};
#endif

}  // namespace transport
}  // namespace mongo

==> mongodb-6.0.22.gh.tar.gz: mongo-r6.0.22/src/mongo/transport/ssl_connection_context.h <==
/**
 *    Copyright (C) 2020-present MongoDB, Inc.
 *
 *    This program is free software: you can redistribute it and/or modify
 *    it under the terms of the Server Side Public License, version 1,
 *    as published by MongoDB, Inc.
 *
 *    This program is distributed in the hope that it will be useful,
 *    but WITHOUT ANY WARRANTY; without even the implied warranty of
 *    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *    Server Side Public License for more details.
 *
 *    You should have received a copy of the Server Side Public License
 *    along with this program. If not, see
 *    <http://www.mongodb.com/licensing/server-side-public-license>.
 *
 *    As a special exception, the copyright holders give permission to link the
 *    code of portions of this program with the OpenSSL library under certain
 *    conditions as described in each individual source file and distribute
 *    linked combinations including the program with the OpenSSL library. You
 *    must comply with the Server Side Public License in all respects for
 *    all of the code used other than as permitted herein. If you modify file(s)
 *    with this exception, you may extend this exception to your version of the
 *    file(s), but you are not obligated to do so. If you do not wish to do so,
 *    delete this exception statement from your version. If you delete this
 *    exception statement from all source files in the program, then also delete
 *    it in the license file.
 */

#pragma once

#include <memory>

#include "mongo/config.h"
#include "mongo/util/net/ssl_options.h"
#include "mongo/util/net/ssl_types.h"

namespace asio {

namespace ssl {
class context;
}  // namespace ssl
}  // namespace asio

namespace mongo {

class SSLManagerInterface;

namespace transport {

#ifdef MONGO_CONFIG_SSL
struct SSLConnectionContext {
    std::unique_ptr<asio::ssl::context> ingress;
    std::unique_ptr<asio::ssl::context> egress;
    std::shared_ptr<SSLManagerInterface> manager;
    // If this Context was created from transient SSL params this contains the URI of the target
    // cluster. It can also be used to determine if the context is indeed transient.
    boost::optional<std::string> targetClusterURI;

    ~SSLConnectionContext();
};
#endif

#ifndef MONGO_CONFIG_SSL
struct SSLConnectionContext {};
#endif

}  // namespace transport
}  // namespace mongo
